@@ -79,6 +79,9 @@ class JSIIAssembly:
         return result.returncode
 
 
+M = TypeVar("M")
+
+
 class JSIIMeta(_ClassPropertyMeta, type):
     def __new__(
         cls: Type["JSIIMeta"],
@@ -108,8 +111,11 @@ class JSIIMeta(_ClassPropertyMeta, type):
 
         return cast("JSIIMeta", obj)
 
-    def __call__(cls: Type[Any], *args: Any, **kwargs) -> Any:
-        inst = super().__call__(*args, **kwargs)
+    def __call__(cls: Type[M], *args: Any, **kwargs) -> M:
+        # There is no way to constrain the metaclass of a `Type[M]` hint today, so we have to
+        # perform a `cast` trick here in order for MyPy to accept this code as valid... The implicit
+        # arguments to `super()` otherwise are `super(__class__, cls)`, which results in an error.
+        inst = super(JSIIMeta, cast(JSIIMeta, cls)).__call__(*args, **kwargs)
 
         # Register this instance with our reference map.
         _reference_map.register_reference(inst)
@@ -162,6 +168,10 @@ def implements(*interfaces: Type[Any]) -> Callable[[T], T]:
     def deco(cls):
         cls.__jsii_type__ = getattr(cls, "__jsii_type__", None)
         cls.__jsii_ifaces__ = getattr(cls, "__jsii_ifaces__", []) + list(interfaces)
+        cls.__jsii_proxy_class__ = getattr(cls, "__jsii_proxy_class__", lambda: None)
+
+        # https://github.com/agronholm/typeguard/issues/479
+        cls.__protocol_attrs__ = getattr(cls, "__protocol_attrs__", [])
         return cls
 
     return deco
